CaptureEvent class
Response from the capture library based on user interaction. When you use the scanner to scan a barcode, you will recieve a CaptureEvent of the decoded data.
Constructors
- CaptureEvent(int id, int type, dynamic value, [int? handle, dynamic result])
-
CaptureEvent.fromJson(Map<
String, dynamic> json)
Properties
- handle ↔ int?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ int
-
getter/setter pair
- result ↔ dynamic
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ int
-
getter/setter pair
- value ↔ dynamic
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited