CaptureProperty class
Class for properties recieved/submitted in requests to Capture library. Capture properties can represent a device name, device type, monitor mode, etc.
Constructors
- CaptureProperty(int? id, int? type, [dynamic value])
-
CaptureProperty.fromJson(Map<
String, dynamic> json)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited