CaptureDataSourceStatus class

Status properties for data sources in capture events.

Constructors

CaptureDataSourceStatus()

Properties

Disable int
the data source status is disabled
getter/setter pair
Enable int
the data source status is enabled
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
NotSupported int
the data source is not supported
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited