CaptureEventIds class

Ids assigned to each capture event.

Constructors

CaptureEventIds()

Properties

batteryLevel int
Event when the battery Level has changed. Type: kUlong
getter/setter pair
buttons int
Event when the device button status has changed. Type: kUlong
getter/setter pair
decodedData int
Event when Capture has some decoded data available. Type: kDecodedData
getter/setter pair
deviceArrival int
Event when a device has connected or is present. Type: kDeviceInfo
getter/setter pair
deviceDiscovered int
A device has been discovered. Type: kDeviceInfo
getter/setter pair
deviceManagerArrival int
Event when the Device Manager (BLE) is present. Type: kDeviceInfo
getter/setter pair
deviceManagerRemoval int
Event when the Device Manager (BLE) is gone. Type: kDeviceInfo
getter/setter pair
deviceOwnership int
Event when a device ownership has changed. Type: kString
getter/setter pair
deviceRemoval int
Event when a device is no longer present. Type: kDeviceInfo
getter/setter pair
discoveryEnd int
The device discovery has ended. Type: kNone
getter/setter pair
error int
Event when Capture had an error. Type: kUlong
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastID int
The Last Event should always be the last ID in the list of possible events. Type: kNone
getter/setter pair
listenerStarted int
Event when the communication listener thread has started. Type: kUlong
getter/setter pair
notInitialized int
Capture has not been correctly initialized after its first open. Type: kNone
getter/setter pair
power int
Event when a device sends a power change notification. Type: kUlong
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminate int
Event when Capture is terminated. Type: kUlong
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited