ButtonPressMask class

The mask to apply for each button that is pressed

Constructors

ButtonPressMask()

Properties

hashCode int
The hash code for this object.
no setterinherited
left int
The left button is pressed.
getter/setter pair
middle int
The middle button is pressed.
getter/setter pair
power int
The power button is pressed.
getter/setter pair
The right button is pressed.
getter/setter pair
ringDetach int
The Ring is detached from the wrist unit.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited