abort property

int abort
getter/setter pair

Set to notify Capture that the client is shutting down gracefully. Capture will send device removal events followed by a terminate event. Once you receive the terminate event, it is safe to shut down Capture. Device: False Get Type: NotApplicable Set Type: None

Implementation

int abort = -2146435072;