applyConfigDevice property
property to apply a config to a Capture Device (not yet enabled) Device: True Get Type: NotApplicable Set Type: None
Implementation
int applyConfigDevice = 1048582;
property to apply a config to a Capture Device (not yet enabled) Device: True Get Type: NotApplicable Set Type: None
int applyConfigDevice = 1048582;