configuration property
property to set or get the Capture configuration Device: False Get Type: String Set Type: String
Implementation
int configuration = -2141913085;
property to set or get the Capture configuration Device: False Get Type: String Set Type: String
int configuration = -2141913085;