connectReasonDevice property
property to get the Capture Device Connect reason Device: True Get Type: None Set Type: NotApplicable
Implementation
int connectReasonDevice = 65812;
property to get the Capture Device Connect reason Device: True Get Type: None Set Type: NotApplicable
int connectReasonDevice = 65812;