connectionBeepConfigDevice property
property to get or set the Capture Device Connection Beep Configuration. Device: True Get Type: None Set Type: Byte
Implementation
int connectionBeepConfigDevice = 131351;
property to get or set the Capture Device Connection Beep Configuration. Device: True Get Type: None Set Type: Byte
int connectionBeepConfigDevice = 131351;