dataFormatDevice property
property to get or set the Decoded Data Format of a Capture Device Device: True Get Type: None Set Type: Byte
Implementation
int dataFormatDevice = 131083;
property to get or set the Decoded Data Format of a Capture Device Device: True Get Type: None Set Type: Byte
int dataFormatDevice = 131083;