deletePairingBondingDevice property

int deletePairingBondingDevice
getter/setter pair

Set deletes pairing and bonding information off the device. Useful when preparing to pair the Capture device to a different host. Device: True Get Type: NotApplicable Set Type: Byte

Implementation

int deletePairingBondingDevice = 1179907;