deviceSpecific property
Sends an arbitrary get or set command to the device Device: True Get Type: Array Set Type: Array
Implementation
int deviceSpecific = 4456451;
Sends an arbitrary get or set command to the device Device: True Get Type: Array Set Type: Array
int deviceSpecific = 4456451;