disconnectDevice property

int disconnectDevice
getter/setter pair

Instructs the device to drop its connection. Note: After sending this command, the host will be unable to send any subsequent commands to this device. Device: True Get Type: NotApplicable Set Type: Byte

Implementation

int disconnectDevice = 1179921;