flashDevice property
Gets or sets the status of the flash on the SoftScan device. Device: True Get Type: None Set Type: Byte
Implementation
int flashDevice = 131352;
Gets or sets the status of the flash on the SoftScan device. Device: True Get Type: None Set Type: Byte
int flashDevice = 131352;