friendlyNameDevice property

int friendlyNameDevice
getter/setter pair

Gets or sets the friendly name of the device. The friendly name is the name that appears in Bluetooth settings. Device: True Get Type: None Set Type: String

Implementation

int friendlyNameDevice = 327936;