interfaceVersion property

int interfaceVersion
getter/setter pair

Gets the version of the firmware interface that Capture service supports. This can be useful for determining if the Capture service supports a particular hardware feature. Device: False Get Type: None Set Type: NotApplicable

Implementation

int interfaceVersion = -2147418112;