localDecodeActionDevice property

int localDecodeActionDevice
getter/setter pair

Gets or sets the local decode action of the device. Determines how decoded data is acknowledged - i.e. with a beep, rumble, flash or some combination of all three. Device: True Get Type: None Set Type: Byte

Implementation

int localDecodeActionDevice = 131340;