monitorMode property
Gets or sets the log level of various Capture service components (Only works on debug builds of the service). Device: False Get Type: Byte Set Type: Array
Implementation
int monitorMode = -2145124346;
Gets or sets the log level of various Capture service components (Only works on debug builds of the service). Device: False Get Type: Byte Set Type: Array
int monitorMode = -2145124346;