notificationsDevice property

int notificationsDevice
getter/setter pair

Gets or sets subscriptions to various events from the device. Events that can be subscribed to include, trigger press/release, power button press/release, power state and battery level change. Device: True Get Type: None Set Type: Ulong

Implementation

int notificationsDevice = 196883;