overlayViewDevice property
property to get or set the Capture Device Overlay View (SoftScan only) Device: True Get Type: None Set Type: Object
Implementation
int overlayViewDevice = 590105;
property to get or set the Capture Device Overlay View (SoftScan only) Device: True Get Type: None Set Type: Object
int overlayViewDevice = 590105;