pcScCouplerControl property
property to control the PC/SC coupler device by passing an array of bytes often called APDU Device: True Get Type: Array Set Type: Array
Implementation
int pcScCouplerControl = 4456732;
property to control the PC/SC coupler device by passing an array of bytes often called APDU Device: True Get Type: Array Set Type: Array
int pcScCouplerControl = 4456732;