pinCodeDevice property
property to get or set the Capture Device PIN code Device: True Get Type: NotApplicable Set Type: String
Implementation
int pinCodeDevice = 1376514;
property to get or set the Capture Device PIN code Device: True Get Type: NotApplicable Set Type: String
int pinCodeDevice = 1376514;