profileConfigDevice property
property to get or set the Capture Device Profile Configuration Device: True Get Type: None Set Type: Array
Implementation
int profileConfigDevice = 262416;
property to get or set the Capture Device Profile Configuration Device: True Get Type: None Set Type: Array
int profileConfigDevice = 262416;