restoreFactoryDefaultsDevice property
Set resets all the settings on the device to their default values. Device: True Get Type: NotApplicable Set Type: None
Implementation
int restoreFactoryDefaultsDevice = 1048836;
Set resets all the settings on the device to their default values. Device: True Get Type: NotApplicable Set Type: None
int restoreFactoryDefaultsDevice = 1048836;