securityModeDevice property
property to get or set the Capture Device Security Mode Device: True Get Type: None Set Type: Byte
Implementation
int securityModeDevice = 131329;
property to get or set the Capture Device Security Mode Device: True Get Type: None Set Type: Byte
int securityModeDevice = 131329;