standConfigDevice property
property to get or set the Capture Device Stand Configuration Device: True Get Type: None Set Type: Ulong
Implementation
int standConfigDevice = 196890;
property to get or set the Capture Device Stand Configuration Device: True Get Type: None Set Type: Ulong
int standConfigDevice = 196890;