startUpRoleSPPDevice property

int startUpRoleSPPDevice
getter/setter pair

Gets or sets the reconnect behavior of the device when it is powered on in application mode. By default, the device will attempt to reconnect to the last host, but this feature can be turned off using this property. Device: True Get Type: None Set Type: Byte

Implementation

int startUpRoleSPPDevice = 131350;