triggerDevice property

int triggerDevice
getter/setter pair

Sets the trigger of the device - can start or stop a read and enable or disable the physical trigger button on the device. Device: True Get Type: NotApplicable Set Type: Byte

Implementation

int triggerDevice = 1179653;