uniqueDeviceIdentifier property
property to get the BLE Unique Device Identifier that can be used to set favorite with Device: True Get Type: String Set Type: NotApplicable
Implementation
int uniqueDeviceIdentifier = 5308930;
property to get the BLE Unique Device Identifier that can be used to set favorite with Device: True Get Type: String Set Type: NotApplicable
int uniqueDeviceIdentifier = 5308930;