DataConfirmationMode class

Data Confirmation Mode indicates what is expected to the send the Data ACK back to the scanner

Constructors

DataConfirmationMode()

Properties

hashCode int
The hash code for this object.
no setterinherited
modeApp int
the Application confirms the decoded data as it receives them
getter/setter pair
modeCapture int
Capture confirms the decoded data as it receives them and there is one app
getter/setter pair
modeDevice int
the device confirms the decoded data locally
getter/setter pair
modeOff int
use the device configuration (Local Confirmation or App)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited