DataConfirmationRumble class
Define the rumble for data confirmation
Constructors
Properties
- bad ↔ int
-
long rumble for failure
getter/setter pair
- good ↔ int
-
short rumble for success
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- none ↔ int
-
no sound
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited