Disconnect class
Disconnect parameters to instruct the device what to do after disconnection
Constructors
Properties
- disableRadio ↔ int
-
Disconnect and disable radio (low power)
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startProfile ↔ int
-
disconnect and then start the current profile
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited