LocalDecodeAction class

Define the action for a local decode

Constructors

LocalDecodeAction()

Properties

beep int
Beep when a local decode occurs
getter/setter pair
flash int
Flash the LED when a local decode occurs
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
none int
no action
getter/setter pair
rumble int
Rumble when a local decode occurs
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited