MonitorDbg class
Define the monitor feature (DEBUG build only)
Constructors
Properties
- channel ↔ int
-
define the output channel for the debug traces
getter/setter pair
- fileLineLevel ↔ int
-
define the number of lines in the file
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- level ↔ int
-
define the level for the debug traces
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited