Notifications class

Configuration masks for selecting the notifications the device should send to the host

Constructors

Notifications()

Properties

batteryLevelChange int
The device sends a notification when the battery level changed (not supported on all device)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
powerButtonPress int
The device sends a notification when the power button is pressed
getter/setter pair
powerButtonRelease int
The device sends a notification when the power button is released
getter/setter pair
powerState int
The device sends a notification when the power state changes (battery to AC or vice-versa) (not supported on all device)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
triggerButtonPress int
The device sends a notification when the trigger button is pressed
getter/setter pair
triggerButtonRelease int
The device sends a notification when the trigger button is released
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited