batteryLevelChange property
The device sends a notification when the battery level changed (not supported on all device)
Implementation
int batteryLevelChange = 32;
The device sends a notification when the battery level changed (not supported on all device)
int batteryLevelChange = 32;