powerState property
The device sends a notification when the power state changes (battery to AC or vice-versa) (not supported on all device)
Implementation
int powerState = 16;
The device sends a notification when the power state changes (battery to AC or vice-versa) (not supported on all device)
int powerState = 16;