PowerState class
Define the possible power states
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onAc ↔ int
-
The power state in on AC
getter/setter pair
- onBattery ↔ int
-
The power state is on battery
getter/setter pair
- onCradle ↔ int
-
The power state is on cradle
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unknown ↔ int
-
The power state is unknown
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited