ProfileConfig class
Configure a profile for the device (None, Acceptor, Initiator)
Constructors
Properties
- acceptor ↔ int
-
The device is discoverable and will accept any connection
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- initiator ↔ int
-
The device initiates a connection to the Bluetooth address specified in the Profile Configuration
getter/setter pair
- none ↔ int
-
The device is in either acceptor or initiator mode, meaning not even discoverable
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited