initiator property
The device initiates a connection to the Bluetooth address specified in the Profile Configuration
Implementation
int initiator = 2;
The device initiates a connection to the Bluetooth address specified in the Profile Configuration
int initiator = 2;