ProfileSelect class

Select a profile for the device (None, SPP, HID)

Constructors

ProfileSelect()

Properties

hashCode int
The hash code for this object.
no setterinherited
hid int
The device is in Basic mode, sometimes referred as Keyboard emulation
getter/setter pair
none int
The device is in acceptor mode, not trying to connect to any host
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spp int
The device is in App mode
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited