SecurityMode class

Security Mode

Constructors

SecurityMode()

Properties

authentication int
communication protected by authentication
getter/setter pair
authenticationEncryption int
communication protected by authentication and encrytion
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
none int
No security
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited