standMode property
Stand mode Engine always in presentation mode Engine hibernate disabled Scanner turns on immediately Power timers disabled Connection retries forever
Implementation
int standMode = 1;
Stand mode Engine always in presentation mode Engine hibernate disabled Scanner turns on immediately Power timers disabled Connection retries forever
int standMode = 1;