StartUpRoleSpp class
The start up role SPP defines the start up role when using the SPP profile.
Constructors
Properties
- acceptor ↔ int
-
The device returns to acceptor mode, not initiating a connection to a host.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastRole ↔ int
-
The device uses the last role configuration upon startup.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited