Timer class

Identifies the timers used in the device, (trigger lock, disconnected, connected)

Constructors

Timer()

Properties

autoLock int
The trigger button stays ineffective for the specified amount of time or until the device receives a data confirmation command.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
powerOffConnected int
This timer specifies the amount of time the device stays on while it is connected to a host.
getter/setter pair
powerOffDisconnected int
This timer specifies the amount of time the device stays on while it is not connected to any host.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited