autoLock property

int autoLock
getter/setter pair

The trigger button stays ineffective for the specified amount of time or until the device receives a data confirmation command.

Implementation

int autoLock = 1;