powerOffConnected property

int powerOffConnected
getter/setter pair

This timer specifies the amount of time the device stays on while it is connected to a host.

Implementation

int powerOffConnected = 4;