powerOffDisconnected property

int powerOffDisconnected
getter/setter pair

This timer specifies the amount of time the device stays on while it is not connected to any host.

Implementation

int powerOffDisconnected = 2;