TriggerMode class
defines the operational mode of the device
Constructors
Properties
- autoLock ↔ int
-
the device waits for the host to unlock the trigger
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- localOnly ↔ int
-
The device triggers a read only by pressing the trigger button
getter/setter pair
- normalLock ↔ int
-
the device locks and unlocks the trigger locally (default)
getter/setter pair
- presentation ↔ int
-
The device triggers a read automatically without user intervention
getter/setter pair
- remoteAndLocal ↔ int
-
The device triggers a read by pressing the trigger button or by receiving the trigger command
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited