remoteAndLocal property
The device triggers a read by pressing the trigger button or by receiving the trigger command
Implementation
int remoteAndLocal = 2;
The device triggers a read by pressing the trigger button or by receiving the trigger command
int remoteAndLocal = 2;