Property class

Constructors

Property()

Properties

arrayValue List<Object?>?
getter/setter pair
byteValue int?
getter/setter pair
dataSourceValue DataSourceIos?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int?
getter/setter pair
longValue int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringValue String?
getter/setter pair
type int?
getter/setter pair
versionValue Version?
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object message) Property