IosTransportAdaptor class

iOS counterpart for HttpTransport. Given that iOS doesn't require HTTP and we leverage the existing iOS library we have a separate and unique transport builder for iOS.

Inheritance

Constructors

IosTransportAdaptor(Logger? logger, [bool? isWeb, dynamic _binaryMessenger])

Properties

getTransport Function
getter/setter pairinherited
handles List<Params>
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
host String?
getter/setter pair
isWeb bool?
getter/setter pair
logger Logger?
getter/setter pair
loop int
getter/setter pairinherited
onEventNotification Function?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transport IosTransport?
getter/setter pair
transportHandle int?
getter/setter pairinherited
transportNotification IosTransportNotification?
getter/setter pair

Methods

close(int? handle) Future<int>
Piggyback Capture's close and use parameters and interfaces unique to iOS connections
override
convertFromProperty(Property property) CaptureProperty
convertToProperty(CaptureProperty captureProperty, bool fromSetProperty) Property
exceptionHelper(String method, int exceptionType, dynamic ex) → dynamic
generateHandle() int
inherited
getProperty(int? clientOrDeviceHandle, CaptureProperty property) Future<CaptureProperty>
Piggyback Capture's getProperty and use parameters and interfaces unique to iOS connections
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openClient(String host, AppInfo appInfo, Function eventNotification) Future<int?>
Piggyback Capture's openClient and use parameters and interfaces unique to iOS connections. Incorporate iOSTransport connection and start listening to stream.
override
openDevice(int? clientHandle, String guid) Future<int>
Piggyback Capture's openDevice and use parameters and interfaces unique to iOS connections
override
openHelper(IosTransportHandle handle) → dynamic
setProperty(int? clientOrDeviceHandle, CaptureProperty property) Future<CaptureProperty>
Piggyback Capture's setProperty and use parameters and interfaces unique to iOS connections
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited