JRpcRequest class

Wrapper for HTTP request to use json rpc parameters. JRpcRequest is required for use with JsonRpc oriented transport.

Inheritance

Constructors

JRpcRequest(int id, String? method, dynamic params)
JRpcRequest.fromJson(Map<String, dynamic> json)

Properties

hashCode int
The hash code for this object.
no setterinherited
id int?
getter/setter pairinherited
jsonrpc String
getter/setter pairinherited
method String?
getter/setter pair
params ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited