classes/shared_methods library

Functions

convertFromPlatformException(PlatformException exception, dynamic method, dynamic type) → dynamic
Converting a platform exception to a generic CaptureException.
propertySwitchStatement(dynamic prop, dynamic finalVal, dynamic isFromProperty) → dynamic
Helper for determining which property switch to use
toCapturePropertySwitch(dynamic prop, dynamic finalVal) → dynamic
Helper for determining which property should be assigned to the value (used in response) property.
toPropertySwitch(dynamic prop, dynamic finalVal) → dynamic
Helper for determining which property generic value (from response) should be assigned to.
typifyValue(dynamic val, dynamic type) → dynamic
Helper function to determine which type a dynamic value should be.