Transport class

Initial transport Interface. Here is where we check the operating system and determine which subclass transport to use (HttpTransport or IosTransport)

Implementers

Constructors

Transport()

Properties

getTransport Function
getter/setter pair
handles List<Params>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
loop int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transportHandle int?
getter/setter pair

Methods

close(int? handle) Future<int>
generateHandle() int
getProperty(int? clientOrDeviceHandle, CaptureProperty property) Future<CaptureProperty>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openClient(String host, AppInfo appInfo, Function eventNotification) Future<int?>
openDevice(int? clientHandle, String guid) Future<int>
setProperty(int? clientOrDeviceHandle, CaptureProperty property) Future<CaptureProperty>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited