AppInfo class
This is the app information used to access the API. These credentials are generated when you register your app on the Socket Mobile website.
Constructors
Properties
- appIdAndroid ↔ String
-
getter/setter pair
- appIdIos ↔ String
-
getter/setter pair
- appKeyAndroid ↔ String
-
getter/setter pair
- appKeyIos ↔ String
-
getter/setter pair
- developerId ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited