CaptureProperty class

Class for properties recieved/submitted in requests to Capture library. Capture properties can represent a device name, device type, monitor mode, etc.

Constructors

CaptureProperty(int? id, int? type, [dynamic value])
CaptureProperty.fromJson(Map<String, dynamic> json)

Properties

hashCode int
The hash code for this object.
no setterinherited
id int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int?
getter/setter pair
value ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited