CapturePropertyIds class
Ids associated with different properties in capture events.
Constructors
Properties
- abort ↔ int
-
Set to notify Capture that the client is shutting down gracefully.
Capture will send device removal events followed by a terminate
event. Once you receive the terminate event, it is safe to shut
down Capture.
Device: False Get Type: NotApplicable Set Type: None
getter/setter pair
- applyConfigDevice ↔ int
-
property to apply a config to a Capture Device (not yet enabled)
Device: True Get Type: NotApplicable Set Type: None
getter/setter pair
- batteryLevelDevice ↔ int
-
Gets the current battery level of the device. Consider using
kNotificationsDevice to subscribe to battery level change events
instead.
Device: True Get Type: None Set Type: NotApplicable
getter/setter pair
- bluetoothAddressDevice ↔ int
-
Gets the Bluetooth address of the device
Device: True Get Type: None Set Type: NotApplicable
getter/setter pair
-
Gets the current state of each button on the device. Consider using
kNotificationsDevice to subscribe to button events instead.
Device: True Get Type: None Set Type: NotApplicable
getter/setter pair
- capabilitiesDevice ↔ int
-
property to get the Capture Device capabilities
Device: True Get Type: Byte Set Type: NotApplicable
getter/setter pair
- changeIdDevice ↔ int
-
Gets the change id of the device. The change id is a checksum of
all the engine settings - e.g. symbology settings, preamble,
postamble, etc - and can be used to determine if the device
configuration has been altered by another application or using a
command barcode.
Device: True Get Type: None Set Type: NotApplicable
getter/setter pair
- configuration ↔ int
-
property to set or get the Capture configuration
Device: False Get Type: String Set Type: String
getter/setter pair
- connectionBeepConfigDevice ↔ int
-
property to get or set the Capture Device Connection Beep
Configuration.
Device: True Get Type: None Set Type: Byte
getter/setter pair
- connectReasonDevice ↔ int
-
property to get the Capture Device Connect reason
Device: True Get Type: None Set Type: NotApplicable
getter/setter pair
- dataConfirmationAction ↔ int
-
Gets or sets the data confirmation action. Data confirmation action
determines how good or bad data is acknowledged.
Device: False Get Type: None Set Type: Ulong
getter/setter pair
- dataConfirmationDevice ↔ int
-
Sends an acknowledgement to the device. Acknowledgement can either
be positive or negative - a.k.a. good scan or bad scan.
Device: True Get Type: NotApplicable Set Type: Ulong
getter/setter pair
- dataConfirmationMode ↔ int
-
Gets or sets the data confirmation mode. The data confirmation mode
determines who acknowledges whether the data received was good or
bad.
Device: False Get Type: None Set Type: Byte
getter/setter pair
- dataFormatDevice ↔ int
-
property to get or set the Decoded Data Format of a Capture Device
Device: True Get Type: None Set Type: Byte
getter/setter pair
- dataSourceDevice ↔ int
-
property to get or set the data source status / information
Device: True Get Type: DataSource Set Type: DataSource
getter/setter pair
- dataStoreDevice ↔ int
-
Gets or sets arbitrary bytes to store on the device. The device has
16 storage locations which can hold up to 64 bytes each.
Device: True Get Type: Array Set Type: Array
getter/setter pair
- deletePairingBondingDevice ↔ int
-
Set deletes pairing and bonding information off the device. Useful
when preparing to pair the Capture device to a different host.
Device: True Get Type: NotApplicable Set Type: Byte
getter/setter pair
- deviceSpecific ↔ int
-
Sends an arbitrary get or set command to the device
Device: True Get Type: Array Set Type: Array
getter/setter pair
- deviceType ↔ int
-
Gets the model of the device
Device: True Get Type: None Set Type: NotApplicable
getter/setter pair
- disconnectDevice ↔ int
-
Instructs the device to drop its connection. Note: After sending
this command, the host will be unable to send any subsequent
commands to this device.
Device: True Get Type: NotApplicable Set Type: Byte
getter/setter pair
- favorite ↔ int
-
property to set or get the BLE favorites for a Device Manager
Device: True Get Type: None Set Type: String
getter/setter pair
- flashDevice ↔ int
-
Gets or sets the status of the flash on the SoftScan device.
Device: True Get Type: None Set Type: Byte
getter/setter pair
- friendlyNameDevice ↔ int
-
Gets or sets the friendly name of the device. The friendly name is
the name that appears in Bluetooth settings.
Device: True Get Type: None Set Type: String
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- interfaceVersion ↔ int
-
Gets the version of the firmware interface that Capture service
supports. This can be useful for determining if the Capture service
supports a particular hardware feature.
Device: False Get Type: None Set Type: NotApplicable
getter/setter pair
- localAcknowledgmentDevice ↔ int
-
Gets or sets local device acknowledgement. When enabled, the device
acknowledges decoded data as soon as it is decoded. When disabled,
the device waits for the host to acknowledge decoded data and the
trigger will be locked until acknowledgement is received or the
trigger lock timeout has elapsed.
Device: True Get Type: None Set Type: Byte
getter/setter pair
- localDecodeActionDevice ↔ int
-
Gets or sets the local decode action of the device. Determines how
decoded data is acknowledged - i.e. with a beep, rumble, flash or
some combination of all three.
Device: True Get Type: None Set Type: Byte
getter/setter pair
- monitorMode ↔ int
-
Gets or sets the log level of various Capture service components
(Only works on debug builds of the service).
Device: False Get Type: Byte Set Type: Array
getter/setter pair
- notificationsDevice ↔ int
-
Gets or sets subscriptions to various events from the device.
Events that can be subscribed to include, trigger press/release,
power button press/release, power state and battery level change.
Device: True Get Type: None Set Type: Ulong
getter/setter pair
- overlayViewDevice ↔ int
-
property to get or set the Capture Device Overlay View (SoftScan
only)
Device: True Get Type: None Set Type: Object
getter/setter pair
- pcScCouplerControl ↔ int
-
property to control the PC/SC coupler device by passing an array of bytes often called APDU
Device: True Get Type: Array Set Type: Array
getter/setter pair
- pcScTagTransmit ↔ int
-
property to transmit through PC/SC an array of bytes often called APDU
Device: True Get Type: Array Set Type: Array
getter/setter pair
- pinCodeDevice ↔ int
-
property to get or set the Capture Device PIN code
Device: True Get Type: NotApplicable Set Type: String
getter/setter pair
- postambleDevice ↔ int
-
Gets or sets a postamble for data decoded by the device. When set,
the postamble is added to the end of the decoded data.
Device: True Get Type: None Set Type: String
getter/setter pair
- powerStateDevice ↔ int
-
Gets the current power state of the device. Consider using
kNotificationsDevice to subscribe to power state events instead.
Device: True Get Type: None Set Type: NotApplicable
getter/setter pair
- preambleDevice ↔ int
-
Gets or sets a preamble for data decoded by the device. When set,
the preamble is added in front of the decoded data.
Device: True Get Type: None Set Type: String
getter/setter pair
- profileConfigDevice ↔ int
-
property to get or set the Capture Device Profile Configuration
Device: True Get Type: None Set Type: Array
getter/setter pair
- restoreFactoryDefaultsDevice ↔ int
-
Set resets all the settings on the device to their default values.
Device: True Get Type: NotApplicable Set Type: None
getter/setter pair
- rumbleConfigDevice ↔ int
-
Gets or sets the rumble configuration of the device. There are
separate rumble configurations for when a good scan is acknowledged
locally (by the Capture device) and when it is acknowledged by the
host. The same applies to the bad scan rumble configuration.
Device: True Get Type: Byte Set Type: Array
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- securityModeDevice ↔ int
-
property to get or set the Capture Device Security Mode
Device: True Get Type: None Set Type: Byte
getter/setter pair
- setPowerOffDevice ↔ int
-
Set turns the device off
Device: True Get Type: NotApplicable Set Type: None
getter/setter pair
- softScanStatus ↔ int
-
property to get or set the SoftScan status
(iOS only)
Device: False Get Type: None Set Type: Byte
getter/setter pair
- soundConfigDevice ↔ int
-
Gets or sets the sound configuration of the device. There are
separate sound configurations for when a good scan is acknowledged
locally (by the Capture device) and when it is acknowledged by the
host. The same applies to the bad scan sound configuration.
Device: True Get Type: Byte Set Type: Array
getter/setter pair
- standConfigDevice ↔ int
-
property to get or set the Capture Device Stand Configuration
Device: True Get Type: None Set Type: Ulong
getter/setter pair
- startDiscovery ↔ int
-
property to start a BLE discovery from a Device Manager
Device: True Get Type: NotApplicable Set Type: Ulong
getter/setter pair
- startUpRoleSPPDevice ↔ int
-
Gets or sets the reconnect behavior of the device when it is
powered on in application mode. By default, the device will attempt
to reconnect to the last host, but this feature can be turned off
using this property.
Device: True Get Type: None Set Type: Byte
getter/setter pair
- statisticCountersDevice ↔ int
-
Gets the statistics counters of the device. Counters record the
absolute number of times a particular event has occurred.
Device: True Get Type: None Set Type: NotApplicable
getter/setter pair
- timersDevice ↔ int
-
Gets or sets the trigger lock and auto-off timers. The trigger lock
determines how long the trigger remains locked after decoding data
without receiving confirmation. There are two auto-off timers, one
for when the device is connected to a host and one for when it is
not.
Device: True Get Type: None Set Type: Array
getter/setter pair
- triggerDevice ↔ int
-
Sets the trigger of the device - can start or stop a read and
enable or disable the physical trigger button on the device.
Device: True Get Type: NotApplicable Set Type: Byte
getter/setter pair
- uniqueDeviceIdentifier ↔ int
-
property to get the BLE Unique Device Identifier that can be used to set favorite with
Device: True Get Type: String Set Type: NotApplicable
getter/setter pair
- version ↔ int
-
Gets the Capture service version.
Device: False Get Type: None Set Type: NotApplicable
getter/setter pair
- versionDevice ↔ int
-
Gets the firmware version of the device
Device: True Get Type: None Set Type: NotApplicable
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited