friendlyNameDevice property
Gets or sets the friendly name of the device. The friendly name is the name that appears in Bluetooth settings. Device: True Get Type: None Set Type: String
Implementation
int friendlyNameDevice = 327936;
Gets or sets the friendly name of the device. The friendly name is the name that appears in Bluetooth settings. Device: True Get Type: None Set Type: String
int friendlyNameDevice = 327936;