postambleDevice property
Gets or sets a postamble for data decoded by the device. When set, the postamble is added to the end of the decoded data. Device: True Get Type: None Set Type: String
Implementation
int postambleDevice = 327688;
Gets or sets a postamble for data decoded by the device. When set, the postamble is added to the end of the decoded data. Device: True Get Type: None Set Type: String
int postambleDevice = 327688;