preambleDevice property
Gets or sets a preamble for data decoded by the device. When set, the preamble is added in front of the decoded data. Device: True Get Type: None Set Type: String
Implementation
int preambleDevice = 327687;
Gets or sets a preamble for data decoded by the device. When set, the preamble is added in front of the decoded data. Device: True Get Type: None Set Type: String
int preambleDevice = 327687;