DataFormat class
Identifies the data format the device should send the data to the host
Constructors
Properties
- dataOnly ↔ int
-
The device sends only the tag data, (valid only for D600 NFC devices)
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- idOnly ↔ int
-
The device sends only the RFID tag ID, (valid only for D600 NFC devices)
getter/setter pair
- packet ↔ int
-
The device sends the data embedded in a protocol packet (default)
getter/setter pair
- raw ↔ int
-
The device sends the data without any protocol overhead
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tagTypeAndData ↔ int
-
The device sends the tag type and the tag data, (valid only for D600 NFC devices)
getter/setter pair
- tagTypeAndId ↔ int
-
The device sends the tag type and RFID tag ID, (valid only for D600 NFC devices)
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited