StandConfig class
The stand configuration defines the operational mode of the device when used with a stand.
Constructors
Properties
- autoMode ↔ int
-
Auto mode On stand engine in presentation mode On stand engine hibernate
disabled On stand charging led state not show On stand scanner turns on
immediately On stand power timers disabled On stand connection retries
forever Off stand does nothing, engine remains in presentation mode Off
stand trigger press causes engine to enter level mode Engine in level
mode battery led state reported Engine in level mode hibernate enabled
Engine in level mode power off timers running Engine in level mode
connection retries halt after max count
getter/setter pair
- detectMode ↔ int
-
Detect mode On stand engine in presentation mode On stand engine
hibernate disabled On stand charging led state not show On stand
scanner turns on immediately On stand power timers disabled On stand
connection retries forever Off stand engine in level mode Off stand
battery led state reported Off stand engine hibernate enabled Off stand
power off timers running Off stand connection retries halt after max
count
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mobileMode ↔ int
-
Mobile mode Works like today existing firmware Engine is always in
trigger mode Engine hibernate enabled
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- standMode ↔ int
-
Stand mode Engine always in presentation mode Engine hibernate
disabled Scanner turns on immediately Power timers disabled Connection
retries forever
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited