powerOffConnected property
This timer specifies the amount of time the device stays on while it is connected to a host.
Implementation
int powerOffConnected = 4;
This timer specifies the amount of time the device stays on while it is connected to a host.
int powerOffConnected = 4;