powerOffDisconnected property
This timer specifies the amount of time the device stays on while it is not connected to any host.
Implementation
int powerOffDisconnected = 2;
This timer specifies the amount of time the device stays on while it is not connected to any host.
int powerOffDisconnected = 2;