close method
Piggyback Capture's close and use parameters and interfaces unique to http connections Implement JSON Rpc protocols.
Implementation
@override
/// Piggyback Capture's close and use parameters and interfaces unique to http connections
/// Implement JSON Rpc protocols.
Future<int> close(int? handle) async {
JRpcRequest closeRequest =
JRpcRequest(this._getJsonRpcId(), 'close', Params(handle));
try {
await this.sendRequest(closeRequest);
return SktErrors.ESKT_NOERROR;
} on CaptureException {
rethrow;
} catch (e) {
throw CaptureException(SktErrors.ESKT_UNABLEDEINITIALIZE, 'The object cannot be un-initialized', e.toString());
}
}